@@ -20,7 +20,9 @@ from flask.views import MethodView
 from werkzeug.utils import find_modules
 
 
-def register_blueprints(app, import_path, bp_name="bp"):
+def register_blueprints(
+    app, import_path, bp_name="bp", include_packages=False, recursive=False
+):
     """Register all Blueprint instances on the specified Flask application found
     in all modules for the specified package.
 
@@ -28,7 +30,9 @@ def register_blueprints(app, import_path, bp_name="bp"):
     :param import_path: the dotted path for the package to find child modules.
     :param bp_name: Blueprint name in views.
     """
-    for name in find_modules(import_path, include_packages=True):
+    for name in find_modules(
+        import_path, include_packages=include_packages, recursive=recursive
+    ):
         mod = importlib.import_module(name)
         bp = getattr(mod, bp_name, None)
         if isinstance(bp, Blueprint):
